@@ -2,18 +2,7 @@
 #
 # Copyright 2016 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
-
+# SPDX-License-Identifier: Apache-2.0
 r"""
 ====================================================
 Blacklist various Python calls known to be dangerous
@@ -27,7 +16,8 @@ ast.Call nodes.
 B301: pickle
 ------------
 
-Pickle library appears to be in use, possible security issue.
+Pickle and modules that wrap it can be unsafe when used to
+deserialize untrusted data, possible security issue.
 
 +------+---------------------+------------------------------------+-----------+
 | ID   |  Name               |  Calls                             |  Severity |
@@ -38,6 +28,11 @@ Pickle library appears to be in use, possible security issue.
 |      |                     | - cPickle.loads                    |           |
 |      |                     | - cPickle.load                     |           |
 |      |                     | - cPickle.Unpickler                |           |
+|      |                     | - dill.loads                       |           |
+|      |                     | - dill.load                        |           |
+|      |                     | - dill.Unpickler                   |           |
+|      |                     | - shelve.open                      |           |
+|      |                     | - shelve.DbfilenameShelf           |           |
 +------+---------------------+------------------------------------+-----------+
 
 B302: marshal
@@ -55,17 +50,25 @@ Deserialization with the marshal module is possibly dangerous.
 B303: md5
 ---------
 
-Use of insecure MD2, MD4, or MD5 hash function.
+Use of insecure MD2, MD4, MD5, or SHA1 hash function.
 
 +------+---------------------+------------------------------------+-----------+
 | ID   |  Name               |  Calls                             |  Severity |
 +======+=====================+====================================+===========+
 | B303 | md5                 | - hashlib.md5                      | Medium    |
+|      |                     | - hashlib.sha1                     |           |
 |      |                     | - Crypto.Hash.MD2.new              |           |
 |      |                     | - Crypto.Hash.MD4.new              |           |
 |      |                     | - Crypto.Hash.MD5.new              |           |
+|      |                     | - Crypto.Hash.SHA.new              |           |
+|      |                     | - Cryptodome.Hash.MD2.new          |           |
+|      |                     | - Cryptodome.Hash.MD4.new          |           |
+|      |                     | - Cryptodome.Hash.MD5.new          |           |
+|      |                     | - Cryptodome.Hash.SHA.new          |           |
 |      |                     | - cryptography.hazmat.primitives   |           |
 |      |                     |   .hashes.MD5                      |           |
+|      |                     | - cryptography.hazmat.primitives   |           |
+|      |                     |   .hashes.SHA1                     |           |
 +------+---------------------+------------------------------------+-----------+
 
 B304 - B305: ciphers and modes
@@ -82,6 +85,11 @@ as AES.
 |      |                     | - Crypto.Cipher.Blowfish.new       |           |
 |      |                     | - Crypto.Cipher.DES.new            |           |
 |      |                     | - Crypto.Cipher.XOR.new            |           |
+|      |                     | - Cryptodome.Cipher.ARC2.new       |           |
+|      |                     | - Cryptodome.Cipher.ARC4.new       |           |
+|      |                     | - Cryptodome.Cipher.Blowfish.new   |           |
+|      |                     | - Cryptodome.Cipher.DES.new        |           |
+|      |                     | - Cryptodome.Cipher.XOR.new        |           |
 |      |                     | - cryptography.hazmat.primitives   |           |
 |      |                     |   .ciphers.algorithms.ARC4         |           |
 |      |                     | - cryptography.hazmat.primitives   |           |
@@ -124,20 +132,19 @@ be reviewed.
 +------+---------------------+------------------------------------+-----------+
 | ID   |  Name               |  Calls                             |  Severity |
 +======+=====================+====================================+===========+
-| B308 | mark_safe           | - mark_safe                        | Medium    |
+| B308 | mark_safe           | - django.utils.safestring.mark_safe| Medium    |
 +------+---------------------+------------------------------------+-----------+
 
 B309: httpsconnection
 ---------------------
 
-Use of HTTPSConnection does not provide security, see
-https://wiki.openstack.org/wiki/OSSN/OSSN-0033
+Use of HTTPSConnection on older versions of Python prior to 2.7.9 and 3.4.3 do
+not provide security, see https://wiki.openstack.org/wiki/OSSN/OSSN-0033
 
 +------+---------------------+------------------------------------+-----------+
 | ID   |  Name               |  Calls                             |  Severity |
 +======+=====================+====================================+===========+
-| B309 | httpsconnection     | - mark_safe                        | Medium    |
-|      |                     | - httplib.HTTPSConnection          |           |
+| B309 | httpsconnection     | - httplib.HTTPSConnection          | Medium    |
 |      |                     | - http.client.HTTPSConnection      |           |
 |      |                     | - six.moves.http_client            |           |
 |      |                     |   .HTTPSConnection                 |           |
@@ -184,6 +191,7 @@ purposes.
 |      |                     | - random.randrange                 |           |
 |      |                     | - random.randint                   |           |
 |      |                     | - random.choice                    |           |
+|      |                     | - random.choices                   |           |
 |      |                     | - random.uniform                   |           |
 |      |                     | - random.triangular                |           |
 +------+---------------------+------------------------------------+-----------+
@@ -204,7 +212,7 @@ B313 - B320: XML
 ----------------
 
 Most of this is based off of Christian Heimes' work on defusedxml:
-https://pypi.python.org/pypi/defusedxml/#defusedxml-sax
+https://pypi.org/project/defusedxml/#defusedxml-sax
 
 Using various XLM methods to parse untrusted XML data is known to be vulnerable
 to XML attacks. Methods should be replaced with their defusedxml equivalents.
@@ -237,9 +245,6 @@ to XML attacks. Methods should be replaced with their defusedxml equivalents.
 | B319 | xml_bad_pulldom     | - xml.dom.pulldom.parse            | Medium    |
 |      |                     | - xml.dom.pulldom.parseString      |           |
 +------+---------------------+------------------------------------+-----------+
-| B319 | xml_bad_pulldom     | - xml.dom.pulldom.parse            | Medium    |
-|      |                     | - xml.dom.pulldom.parseString      |           |
-+------+---------------------+------------------------------------+-----------+
 | B320 | xml_bad_etree       | - lxml.etree.parse                 | Medium    |
 |      |                     | - lxml.etree.fromstring            |           |
 |      |                     | - lxml.etree.RestrictedElement     |           |
@@ -261,17 +266,51 @@ SSH/SFTP/SCP or some other encrypted protocol.
 +------+---------------------+------------------------------------+-----------+
 
 B322: input
-------------
+-----------
+
+The check for this call has been removed.
 
 The input method in Python 2 will read from standard input, evaluate and
 run the resulting string as python source code. This is similar, though in
-many ways worse, then using eval. On Python 2, use raw_input instead, input
+many ways worse, than using eval. On Python 2, use raw_input instead, input
 is safe in Python 3.
 
 +------+---------------------+------------------------------------+-----------+
 | ID   |  Name               |  Calls                             |  Severity |
 +======+=====================+====================================+===========+
-| B322 | ftplib              | - input                            | High      |
+| B322 | input               | - input                            | High      |
++------+---------------------+------------------------------------+-----------+
+
+B323: unverified_context
+------------------------
+
+By default, Python will create a secure, verified ssl context for use in such
+classes as HTTPSConnection. However, it still allows using an insecure
+context via the _create_unverified_context that reverts to the previous
+behavior that does not validate certificates or perform hostname checks.
+
++------+---------------------+------------------------------------+-----------+
+| ID   |  Name               |  Calls                             |  Severity |
++======+=====================+====================================+===========+
+| B323 | unverified_context  | - ssl._create_unverified_context   | Medium    |
++------+---------------------+------------------------------------+-----------+
+
+B325: tempnam
+--------------
+
+Use of os.tempnam() and os.tmpnam() is vulnerable to symlink attacks. Consider
+using tmpfile() instead.
+
+For further information:
+    https://docs.python.org/2.7/library/os.html#os.tempnam
+    https://docs.python.org/3/whatsnew/3.0.html?highlight=tempnam
+    https://bugs.python.org/issue17880
+
++------+---------------------+------------------------------------+-----------+
+| ID   |  Name               |  Calls                             |  Severity |
++======+=====================+====================================+===========+
+| B325 | tempnam             | - os.tempnam                       | Medium    |
+|      |                     | - os.tmpnam                        |           |
 +------+---------------------+------------------------------------+-----------+
 
 """
@@ -290,7 +329,6 @@ def gen_blacklist():
 
     :return: a dictionary mapping node types to a list of blacklist data
     """
-
     sets = []
     sets.append(utils.build_conf_dict(
         'pickle', 'B301',
@@ -299,24 +337,37 @@ def gen_blacklist():
          'pickle.Unpickler',
          'cPickle.loads',
          'cPickle.load',
-         'cPickle.Unpickler'],
-        'Pickle library appears to be in use, possible security issue.'
-        ))
+         'cPickle.Unpickler',
+         'dill.loads',
+         'dill.load',
+         'dill.Unpickler',
+         'shelve.open',
+         'shelve.DbfilenameShelf'],
+        'Pickle and modules that wrap it can be unsafe when used to '
+        'deserialize untrusted data, possible security issue.'
+    ))
 
     sets.append(utils.build_conf_dict(
         'marshal', 'B302', ['marshal.load', 'marshal.loads'],
         'Deserialization with the marshal module is possibly dangerous.'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'md5', 'B303',
         ['hashlib.md5',
+         'hashlib.sha1',
          'Crypto.Hash.MD2.new',
          'Crypto.Hash.MD4.new',
          'Crypto.Hash.MD5.new',
-         'cryptography.hazmat.primitives.hashes.MD5'],
-        'Use of insecure MD2, MD4, or MD5 hash function.'
-        ))
+         'Crypto.Hash.SHA.new',
+         'Cryptodome.Hash.MD2.new',
+         'Cryptodome.Hash.MD4.new',
+         'Cryptodome.Hash.MD5.new',
+         'Cryptodome.Hash.SHA.new',
+         'cryptography.hazmat.primitives.hashes.MD5',
+         'cryptography.hazmat.primitives.hashes.SHA1'],
+        'Use of insecure MD2, MD4, MD5, or SHA1 hash function.'
+    ))
 
     sets.append(utils.build_conf_dict(
         'ciphers', 'B304',
@@ -325,45 +376,51 @@ def gen_blacklist():
          'Crypto.Cipher.Blowfish.new',
          'Crypto.Cipher.DES.new',
          'Crypto.Cipher.XOR.new',
+         'Cryptodome.Cipher.ARC2.new',
+         'Cryptodome.Cipher.ARC4.new',
+         'Cryptodome.Cipher.Blowfish.new',
+         'Cryptodome.Cipher.DES.new',
+         'Cryptodome.Cipher.XOR.new',
          'cryptography.hazmat.primitives.ciphers.algorithms.ARC4',
          'cryptography.hazmat.primitives.ciphers.algorithms.Blowfish',
          'cryptography.hazmat.primitives.ciphers.algorithms.IDEA'],
         'Use of insecure cipher {name}. Replace with a known secure'
         ' cipher such as AES.',
         'HIGH'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'cipher_modes', 'B305',
         ['cryptography.hazmat.primitives.ciphers.modes.ECB'],
         'Use of insecure cipher mode {name}.'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'mktemp_q', 'B306', ['tempfile.mktemp'],
         'Use of insecure and deprecated function (mktemp).'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'eval', 'B307', ['eval'],
         'Use of possibly insecure function - consider using safer '
         'ast.literal_eval.'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
-        'mark_safe', 'B308', ['mark_safe'],
+        'mark_safe', 'B308', ['django.utils.safestring.mark_safe'],
         'Use of mark_safe() may expose cross-site scripting '
         'vulnerabilities and should be reviewed.'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'httpsconnection', 'B309',
         ['httplib.HTTPSConnection',
          'http.client.HTTPSConnection',
          'six.moves.http_client.HTTPSConnection'],
-        'Use of HTTPSConnection does not provide security, see '
+        'Use of HTTPSConnection on older versions of Python prior to 2.7.9 '
+        'and 3.4.3 do not provide security, see '
         'https://wiki.openstack.org/wiki/OSSN/OSSN-0033'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'urllib_urlopen', 'B310',
@@ -383,7 +440,7 @@ def gen_blacklist():
          'six.moves.urllib.request.FancyURLopener'],
         'Audit url open for permitted schemes. Allowing use of file:/ or '
         'custom schemes is often unexpected.'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'random', 'B311',
@@ -391,22 +448,23 @@ def gen_blacklist():
          'random.randrange',
          'random.randint',
          'random.choice',
+         'random.choices',
          'random.uniform',
          'random.triangular'],
         'Standard pseudo-random generators are not suitable for '
         'security/cryptographic purposes.',
         'LOW'
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'telnetlib', 'B312', ['telnetlib.*'],
         'Telnet-related functions are being called. Telnet is considered '
         'insecure. Use SSH or some other encrypted protocol.',
         'HIGH'
-        ))
+    ))
 
     # Most of this is based off of Christian Heimes' work on defusedxml:
-    #   https://pypi.python.org/pypi/defusedxml/#defusedxml-sax
+    #   https://pypi.org/project/defusedxml/#defusedxml-sax
 
     xml_msg = ('Using {name} to parse untrusted XML data is known to be '
                'vulnerable to XML attacks. Replace {name} with its '
@@ -420,7 +478,7 @@ def gen_blacklist():
          'xml.etree.cElementTree.fromstring',
          'xml.etree.cElementTree.XMLParser'],
         xml_msg
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'xml_bad_ElementTree', 'B314',
@@ -429,19 +487,19 @@ def gen_blacklist():
          'xml.etree.ElementTree.fromstring',
          'xml.etree.ElementTree.XMLParser'],
         xml_msg
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'xml_bad_expatreader', 'B315', ['xml.sax.expatreader.create_parser'],
         xml_msg
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'xml_bad_expatbuilder', 'B316',
         ['xml.dom.expatbuilder.parse',
          'xml.dom.expatbuilder.parseString'],
         xml_msg
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'xml_bad_sax', 'B317',
@@ -449,21 +507,21 @@ def gen_blacklist():
          'xml.sax.parseString',
          'xml.sax.make_parser'],
         xml_msg
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'xml_bad_minidom', 'B318',
         ['xml.dom.minidom.parse',
          'xml.dom.minidom.parseString'],
         xml_msg
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'xml_bad_pulldom', 'B319',
         ['xml.dom.pulldom.parse',
          'xml.dom.pulldom.parseString'],
         xml_msg
-        ))
+    ))
 
     sets.append(utils.build_conf_dict(
         'xml_bad_etree', 'B320',
@@ -476,7 +534,7 @@ def gen_blacklist():
         ('Using {name} to parse untrusted XML data is known to be '
          'vulnerable to XML attacks. Replace {name} with its '
          'defusedxml equivalent function.')
-        ))
+    ))
 
     # end of XML tests
 
@@ -485,15 +543,25 @@ def gen_blacklist():
         'FTP-related functions are being called. FTP is considered '
         'insecure. Use SSH/SFTP/SCP or some other encrypted protocol.',
         'HIGH'
-        ))
+    ))
+
+    # skipped B322 as the check for a call to input() has been removed
 
     sets.append(utils.build_conf_dict(
-        'input', 'B322', ['input'],
-        'The input method in Python 2 will read from standard input, '
-        'evaluate and run the resulting string as python source code. This '
-        'is similar, though in many ways worse, then using eval. On Python '
-        '2, use raw_input instead, input is safe in Python 3.',
-        'HIGH'
-        ))
+        'unverified_context', 'B323', ['ssl._create_unverified_context'],
+        'By default, Python will create a secure, verified ssl context for '
+        'use in such classes as HTTPSConnection. However, it still allows '
+        'using an insecure context via the _create_unverified_context that '
+        'reverts to the previous behavior that does not validate certificates '
+        'or perform hostname checks.'
+    ))
+
+    # skipped B324 (used in bandit/plugins/hashlib_new_insecure_functions.py)
+
+    sets.append(utils.build_conf_dict(
+        'tempnam', 'B325', ['os.tempnam', 'os.tmpnam'],
+        'Use of os.tempnam() and os.tmpnam() is vulnerable to symlink '
+        'attacks. Consider using tmpfile() instead.'
+    ))
 
     return {'Call': sets}
