@@ -2,21 +2,10 @@
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 import logging
 
-import six
 import yaml
 
 from bandit.core import constants
@@ -47,11 +36,23 @@ class BanditConfig(object):
                 raise utils.ConfigError("Could not read config file.",
                                         config_file)
 
-            try:
-                self._config = yaml.safe_load(f)
-                self.validate(config_file)
-            except yaml.YAMLError:
-                raise utils.ConfigError("Error parsing file.", config_file)
+            if config_file.endswith('.toml'):
+                import toml
+                try:
+                    with f:
+                        self._config = toml.load(f)['tool']['bandit']
+                except toml.TomlDecodeError as err:
+                    LOG.error(err)
+                    raise utils.ConfigError("Error parsing file.", config_file)
+            else:
+                try:
+                    with f:
+                        self._config = yaml.safe_load(f)
+                except yaml.YAMLError as err:
+                    LOG.error(err)
+                    raise utils.ConfigError("Error parsing file.", config_file)
+
+            self.validate(config_file)
 
             # valid config must be a dict
             if not isinstance(self._config, dict):
@@ -132,7 +133,7 @@ class BanditConfig(object):
         extman = extension_loader.MANAGER
 
         updated_profiles = {}
-        for name, profile in six.iteritems(self.get_option('profiles') or {}):
+        for name, profile in (self.get_option('profiles') or {}).items():
             # NOTE(tkelsey): can't use default of get() because value is
             # sometimes explicity 'None', for example when the list if given in
             # yaml but not populated with any values.
@@ -151,7 +152,7 @@ class BanditConfig(object):
         bad_calls = self.get_option('blacklist_calls') or {}
         bad_calls = bad_calls.get('bad_name_sets', {})
         for item in bad_calls:
-            for key, val in six.iteritems(item):
+            for key, val in item.items():
                 val['name'] = key
                 val['message'] = val['message'].replace('{func}', '{name}')
                 bad_calls_list.append(val)
@@ -159,7 +160,7 @@ class BanditConfig(object):
         bad_imports = self.get_option('blacklist_imports') or {}
         bad_imports = bad_imports.get('bad_import_sets', {})
         for item in bad_imports:
-            for key, val in six.iteritems(item):
+            for key, val in item.items():
                 val['name'] = key
                 val['message'] = val['message'].replace('{module}', '{name}')
                 val['qualnames'] = val['imports']
@@ -179,7 +180,7 @@ class BanditConfig(object):
                 data.remove(name)
                 data.add('B001')
 
-        for name, profile in six.iteritems(profiles):
+        for name, profile in profiles.items():
             blacklist = {}
             include = profile['include']
             exclude = profile['exclude']
