@@ -1,17 +1,7 @@
 # Copyright (c) 2015 Hewlett Packard Enterprise
 # -*- coding:utf-8 -*-
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 r"""
 ==============
@@ -29,6 +19,7 @@ This formatter outputs the issues as plain text.
 
        Severity: Medium   Confidence: High
        Location: examples/yaml_load.py:5
+       More Info: https://bandit.readthedocs.io/en/latest/
     4       ystr = yaml.dump({'a' : 1, 'b' : 2, 'c' : 3})
     5       y = yaml.load(ystr)
     6       yaml.dump(y)
@@ -44,6 +35,7 @@ import logging
 import sys
 
 from bandit.core import constants
+from bandit.core import docs_utils
 from bandit.core import test_properties
 from bandit.formatters import utils
 
@@ -65,7 +57,7 @@ def get_verbose_details(manager):
 def get_metrics(manager):
     bits = []
     bits.append("\nRun metrics:")
-    for (criteria, default) in constants.CRITERIA:
+    for (criteria, _) in constants.CRITERIA:
         bits.append("\tTotal issues (by %s):" % (criteria.lower()))
         for rank in constants.RANKING:
             bits.append("\t\t%s: %s" % (
@@ -84,11 +76,15 @@ def _output_issue_str(issue, indent, show_lineno=True, show_code=True,
     bits.append("%s   Severity: %s   Confidence: %s" % (
         indent, issue.severity.capitalize(), issue.confidence.capitalize()))
 
-    bits.append("%s   Location: %s:%s" % (
-        indent, issue.fname, issue.lineno if show_lineno else ""))
+    bits.append("%s   Location: %s:%s:%s" % (
+        indent, issue.fname, issue.lineno if show_lineno else "",
+        issue.col_offset if show_lineno else ""))
+
+    bits.append("%s   More Info: %s" % (
+        indent, docs_utils.get_url(issue.test_id)))
 
     if show_code:
-        bits.extend([indent + l for l in
+        bits.extend([indent + line for line in
                      issue.get_code(lines, True).split('\n')])
 
     return '\n'.join([bit for bit in bits])
@@ -136,29 +132,31 @@ def report(manager, fileobj, sev_level, conf_level, lines=-1):
     """
 
     bits = []
-    bits.append("Run started:%s" % datetime.datetime.utcnow())
 
-    if manager.verbose:
-        bits.append(get_verbose_details(manager))
+    if not manager.quiet or manager.results_count(sev_level, conf_level):
+        bits.append("Run started:%s" % datetime.datetime.utcnow())
 
-    bits.append("\nTest results:")
-    bits.append(get_results(manager, sev_level, conf_level, lines))
-    bits.append("\nCode scanned:")
-    bits.append('\tTotal lines of code: %i' %
-                (manager.metrics.data['_totals']['loc']))
+        if manager.verbose:
+            bits.append(get_verbose_details(manager))
 
-    bits.append('\tTotal lines skipped (#nosec): %i' %
-                (manager.metrics.data['_totals']['nosec']))
+        bits.append("\nTest results:")
+        bits.append(get_results(manager, sev_level, conf_level, lines))
+        bits.append("\nCode scanned:")
+        bits.append('\tTotal lines of code: %i' %
+                    (manager.metrics.data['_totals']['loc']))
 
-    skipped = manager.get_skipped()
-    bits.append(get_metrics(manager))
-    bits.append("Files skipped (%i):" % len(skipped))
-    bits.extend(["\t%s (%s)" % skip for skip in skipped])
-    result = '\n'.join([bit for bit in bits]) + '\n'
+        bits.append('\tTotal lines skipped (#nosec): %i' %
+                    (manager.metrics.data['_totals']['nosec']))
 
-    with fileobj:
-        wrapped_file = utils.wrap_file_object(fileobj)
-        wrapped_file.write(utils.convert_file_contents(result))
+        skipped = manager.get_skipped()
+        bits.append(get_metrics(manager))
+        bits.append("Files skipped (%i):" % len(skipped))
+        bits.extend(["\t%s (%s)" % skip for skip in skipped])
+        result = '\n'.join([bit for bit in bits]) + '\n'
+
+        with fileobj:
+            wrapped_file = utils.wrap_file_object(fileobj)
+            wrapped_file.write(result)
 
     if fileobj.name != sys.stdout.name:
         LOG.info("Text output written to file: %s", fileobj.name)
