@@ -1,16 +1,6 @@
 # -*- coding:utf-8 -*-
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 r"""
 =============
@@ -27,7 +17,8 @@ This formatter outputs the issues as XML.
     <testsuite name="bandit" tests="1"><testcase
     classname="examples/yaml_load.py" name="blacklist_calls"><error
     message="Use of unsafe yaml load. Allows instantiation of arbitrary
-    objects. Consider yaml.safe_load().&#10;" type="MEDIUM">Test ID: B301
+    objects. Consider yaml.safe_load().&#10;" type="MEDIUM"
+    more_info="https://bandit.readthedocs.io/en/latest/">Test ID: B301
     Severity: MEDIUM Confidence: HIGH Use of unsafe yaml load. Allows
     instantiation of arbitrary objects. Consider yaml.safe_load().
 
@@ -44,7 +35,7 @@ import logging
 import sys
 from xml.etree import cElementTree as ET
 
-import six
+from bandit.core import docs_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -70,16 +61,15 @@ def report(manager, fileobj, sev_level, conf_level, lines=-1):
         text = 'Test ID: %s Severity: %s Confidence: %s\n%s\nLocation %s:%s'
         text = text % (issue.test_id, issue.severity, issue.confidence,
                        issue.text, issue.fname, issue.lineno)
-        ET.SubElement(testcase, 'error', type=issue.severity,
+        ET.SubElement(testcase, 'error',
+                      more_info=docs_utils.get_url(issue.test_id),
+                      type=issue.severity,
                       message=issue.text).text = text
 
     tree = ET.ElementTree(root)
 
     if fileobj.name == sys.stdout.name:
-        if six.PY2:
-            fileobj = sys.stdout
-        else:
-            fileobj = sys.stdout.buffer
+        fileobj = sys.stdout.buffer
     elif fileobj.mode == 'w':
         fileobj.close()
         fileobj = open(fileobj.name, "wb")
