@@ -2,27 +2,20 @@
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 import ast
-import sys
+import re
 
 import bandit
 from bandit.core import test_properties as test
 
 
-CANDIDATES = set(["password", "pass", "passwd", "pwd", "secret", "token",
-                  "secrete"])
+RE_WORDS = "(pas+wo?r?d|pass(phrase)?|pwd|token|secrete?)"
+RE_CANDIDATES = re.compile(
+    '(^{0}$|_{0}_|^{0}_|_{0}$)'.format(RE_WORDS),
+    re.IGNORECASE
+)
 
 
 def _report(value):
@@ -81,26 +74,37 @@ def hardcoded_password_string(context):
 
     """
     node = context.node
-    if isinstance(node.parent, ast.Assign):
+    if isinstance(node._bandit_parent, ast.Assign):
         # looks for "candidate='some_string'"
-        for targ in node.parent.targets:
-            if isinstance(targ, ast.Name) and targ.id in CANDIDATES:
+        for targ in node._bandit_parent.targets:
+            if isinstance(targ, ast.Name) and RE_CANDIDATES.search(targ.id):
                 return _report(node.s)
 
-    elif isinstance(node.parent, ast.Index) and node.s in CANDIDATES:
-        # looks for "dict[candidate]='some_string'"
-        # assign -> subscript -> index -> string
-        assign = node.parent.parent.parent
+    elif (isinstance(node._bandit_parent, ast.Subscript)
+          and RE_CANDIDATES.search(node.s)):
+        # Py39+: looks for "dict[candidate]='some_string'"
+        # subscript -> index -> string
+        assign = node._bandit_parent._bandit_parent
         if isinstance(assign, ast.Assign) and isinstance(assign.value,
                                                          ast.Str):
             return _report(assign.value.s)
 
-    elif isinstance(node.parent, ast.Compare):
+    elif (isinstance(node._bandit_parent, ast.Index)
+          and RE_CANDIDATES.search(node.s)):
+        # looks for "dict[candidate]='some_string'"
+        # assign -> subscript -> index -> string
+        assign = node._bandit_parent._bandit_parent._bandit_parent
+        if isinstance(assign, ast.Assign) and isinstance(assign.value,
+                                                         ast.Str):
+            return _report(assign.value.s)
+
+    elif isinstance(node._bandit_parent, ast.Compare):
         # looks for "candidate == 'some_string'"
-        comp = node.parent
-        if isinstance(comp.left, ast.Name) and comp.left.id in CANDIDATES:
-            if isinstance(comp.comparators[0], ast.Str):
-                return _report(comp.comparators[0].s)
+        comp = node._bandit_parent
+        if isinstance(comp.left, ast.Name):
+            if RE_CANDIDATES.search(comp.left.id):
+                if isinstance(comp.comparators[0], ast.Str):
+                    return _report(comp.comparators[0].s)
 
 
 @test.checks('Call')
@@ -150,7 +154,7 @@ def hardcoded_password_funcarg(context):
     """
     # looks for "function(candidate='some_string')"
     for kw in context.node.keywords:
-        if isinstance(kw.value, ast.Str) and kw.arg in CANDIDATES:
+        if isinstance(kw.value, ast.Str) and RE_CANDIDATES.search(kw.arg):
             return _report(kw.value.s)
 
 
@@ -209,7 +213,6 @@ def hardcoded_password_default(context):
 
     # go through all (param, value)s and look for candidates
     for key, val in zip(context.node.args.args, defs):
-        if isinstance(key, ast.Name):
-            check = key.arg if sys.version_info.major > 2 else key.id  # Py3
-            if isinstance(val, ast.Str) and check in CANDIDATES:
+        if isinstance(key, (ast.Name, ast.arg)):
+            if isinstance(val, ast.Str) and RE_CANDIDATES.search(key.arg):
                 return _report(val.s)
