@@ -2,17 +2,7 @@
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 import ast
 import re
@@ -44,8 +34,7 @@ def gen_config(name):
              'subprocess.call',
              'subprocess.check_call',
              'subprocess.check_output',
-             'utils.execute',
-             'utils.execute_with_timeout'],
+             'subprocess.run'],
 
             # Start a process with a function vulnerable to shell injection.
             'shell':
@@ -85,6 +74,28 @@ def gen_config(name):
             }
 
 
+def has_shell(context):
+    keywords = context.node.keywords
+    result = False
+    if 'shell' in context.call_keywords:
+        for key in keywords:
+            if key.arg == 'shell':
+                val = key.value
+                if isinstance(val, ast.Num):
+                    result = bool(val.n)
+                elif isinstance(val, ast.List):
+                    result = bool(val.elts)
+                elif isinstance(val, ast.Dict):
+                    result = bool(val.keys)
+                elif isinstance(val, ast.Name) and val.id in ['False', 'None']:
+                    result = False
+                elif isinstance(val, ast.NameConstant):
+                    result = val.value
+                else:
+                    result = True
+    return result
+
+
 @test.takes_config('shell_injection')
 @test.checks('Call')
 @test.test_id('B602')
@@ -173,14 +184,14 @@ def subprocess_popen_with_shell_equals_true(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://docs.python.org/3/library/subprocess.html#frequently-used-arguments
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
      - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
 
     .. versionadded:: 0.9.0
-    """
+    """  # noqa: E501
     if config and context.call_function_name_qual in config['subprocess']:
-        if context.check_call_arg_value('shell', 'True'):
+        if has_shell(context):
             if len(context.call_args) > 0:
                 sev = _evaluate_shell_call(context)
                 if sev == bandit.LOW:
@@ -206,7 +217,7 @@ def subprocess_popen_with_shell_equals_true(context, config):
 @test.checks('Call')
 @test.test_id('B603')
 def subprocess_without_shell_equals_true(context, config):
-    """**B603: Test for use of subprocess with shell equals true**
+    """**B603: Test for use of subprocess without shell equals true**
 
     Python possesses many mechanisms to invoke an external executable. However,
     doing so may present a security issue if appropriate care is not taken to
@@ -264,14 +275,14 @@ def subprocess_without_shell_equals_true(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://docs.python.org/3/library/subprocess.html#frequently-used-arguments
      - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.9.0
-    """
+    """  # noqa: E501
     if config and context.call_function_name_qual in config['subprocess']:
-        if not context.check_call_arg_value('shell', 'True'):
+        if not has_shell(context):
             return bandit.Issue(
                 severity=bandit.LOW,
                 confidence=bandit.HIGH,
@@ -325,8 +336,8 @@ def any_other_function_with_shell_equals_true(context, config):
             # Start a process using the subprocess module, or one of its
             wrappers.
             subprocess: [subprocess.Popen, subprocess.call,
-                         subprocess.check_call, subprocess.check_output,
-                         utils.execute, utils.execute_with_timeout]
+                         subprocess.check_call, subprocess.check_output
+                         execute_with_timeout]
 
 
     :Example:
@@ -344,12 +355,12 @@ def any_other_function_with_shell_equals_true(context, config):
     .. seealso::
 
      - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
-     - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html  # noqa
+     - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.9.0
-    """
+    """  # noqa: E501
     if config and context.call_function_name_qual not in config['subprocess']:
-        if context.check_call_arg_value('shell', 'True'):
+        if has_shell(context):
             return bandit.Issue(
                 severity=bandit.MEDIUM,
                 confidence=bandit.LOW,
@@ -375,7 +386,7 @@ def start_process_with_a_shell(context, config):
     invocation is dangerous as it is vulnerable to various shell injection
     attacks. Great care should be taken to sanitize all input in order to
     mitigate this risk. Calls of this type are identified by the use of certain
-    commands which are known to use shells. Bandit will report a MEDIUM
+    commands which are known to use shells. Bandit will report a LOW
     severity warning.
 
     See also:
@@ -418,7 +429,7 @@ def start_process_with_a_shell(context, config):
     .. code-block:: none
 
         >> Issue: Starting a process with a shell: check for injection.
-           Severity: Medium   Confidence: Medium
+           Severity: Low   Confidence: Medium
            Location: examples/os_system.py:3
         2
         3   os.system('/bin/echo hi')
@@ -426,12 +437,12 @@ def start_process_with_a_shell(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/os.html#os.system
-     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://docs.python.org/3/library/os.html#os.system
+     - https://docs.python.org/3/library/subprocess.html#frequently-used-arguments
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.10.0
-    """
+    """  # noqa: E501
     if config and context.call_function_name_qual in config['shell']:
         if len(context.call_args) > 0:
             sev = _evaluate_shell_call(context)
@@ -524,12 +535,12 @@ def start_process_with_no_shell(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/os.html#os.system
-     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://docs.python.org/3/library/os.html#os.system
+     - https://docs.python.org/3/library/subprocess.html#frequently-used-arguments
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.10.0
-    """
+    """  # noqa: E501
 
     if config and context.call_function_name_qual in config['no_shell']:
         return bandit.Issue(
@@ -610,7 +621,7 @@ def start_process_with_partial_path(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/os.html#process-management
+     - https://docs.python.org/3/library/os.html#process-management
 
     .. versionadded:: 0.13.0
     """
