@@ -2,21 +2,13 @@
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 r"""
-Description
------------
+========================================
+B609: Test for use of wildcard injection
+========================================
+
 Python provides a number of methods that emulate the behavior of standard Linux
 command line utilities. Like their Linux counterparts, these commands may take
 a wildcard "\*" character in place of a file system path. This is interpreted
@@ -40,8 +32,8 @@ As well as any method configured in the shell or subprocess injection test
 configurations.
 
 
-Config Options
---------------
+**Config Options:**
+
 This plugin test shares a configuration with others in the same family, namely
 `shell_injection`. This configuration is divided up into three sections,
 `subprocess`, `shell` and `no_shell`. They each list Python calls that spawn
@@ -75,8 +67,8 @@ methods are fully qualified and de-aliased prior to checking.
             - os.execle
 
 
-Sample Output
--------------
+:Example:
+
 .. code-block:: none
 
     >> Issue: Possible wildcard injection in call: subprocess.Popen
@@ -94,22 +86,27 @@ Sample Output
     12   subp.Popen("/bin/chmod *")
 
 
-References
-----------
-- https://security.openstack.org
-- https://en.wikipedia.org/wiki/Wildcard_character
-- http://www.defensecode.com/public/DefenseCode_Unix_WildCards_Gone_Wild.txt
+.. seealso::
+
+ - https://security.openstack.org
+ - https://en.wikipedia.org/wiki/Wildcard_character
+ - https://www.defensecode.com/public/DefenseCode_Unix_WildCards_Gone_Wild.txt
 
 .. versionadded:: 0.9.0
 
 """
 
 import bandit
-from bandit.core.test_properties import *
+from bandit.core import test_properties as test
+from bandit.plugins import injection_shell  # NOTE(tkelsey): shared config
 
 
-@takes_config('shell_injection')
-@checks('Call')
+gen_config = injection_shell.gen_config
+
+
+@test.takes_config('shell_injection')
+@test.checks('Call')
+@test.test_id('B609')
 def linux_commands_wildcard_injection(context, config):
     if not ('shell' in config and 'subprocess' in config):
         return
@@ -137,5 +134,6 @@ def linux_commands_wildcard_injection(context, config):
                             severity=bandit.HIGH,
                             confidence=bandit.MEDIUM,
                             text="Possible wildcard injection in call: %s" %
-                                 context.call_function_name_qual
+                            context.call_function_name_qual,
+                            lineno=context.get_lineno_for_call_arg('shell'),
                         )
