@@ -7,7 +7,6 @@
 import os
 import sys
 
-import six
 import testtools
 
 from bandit.core import config as b_config
@@ -150,22 +149,11 @@ class FunctionalTests(testtools.TestCase):
 
     def test_exec(self):
         '''Test the `exec` example.'''
-        filename = 'exec-{}.py'
-        if six.PY2:
-            filename = filename.format('py2')
-            expect = {
-                'SEVERITY': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 2, 'HIGH': 0},
-                'CONFIDENCE': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 0,
-                               'HIGH': 2}
-            }
-        else:
-            filename = filename.format('py3')
-            expect = {
-                'SEVERITY': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 1, 'HIGH': 0},
-                'CONFIDENCE': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 0,
-                               'HIGH': 1}
-            }
-        self.check_example(filename, expect)
+        expect = {
+            'SEVERITY': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 1, 'HIGH': 0},
+            'CONFIDENCE': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 0, 'HIGH': 1}
+        }
+        self.check_example('exec.py', expect)
 
     def test_hardcoded_passwords(self):
         '''Test for hard-coded passwords.'''
@@ -242,8 +230,8 @@ class FunctionalTests(testtools.TestCase):
     def test_imports_using_importlib(self):
         '''Test for dangerous imports using importlib.'''
         expect = {
-            'SEVERITY': {'UNDEFINED': 0, 'LOW': 2, 'MEDIUM': 0, 'HIGH': 0},
-            'CONFIDENCE': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 0, 'HIGH': 2}
+            'SEVERITY': {'UNDEFINED': 0, 'LOW': 4, 'MEDIUM': 0, 'HIGH': 0},
+            'CONFIDENCE': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 0, 'HIGH': 4}
         }
         self.check_example('imports-with-importlib.py', expect)
 
@@ -286,16 +274,11 @@ class FunctionalTests(testtools.TestCase):
 
     def test_os_chmod(self):
         '''Test setting file permissions.'''
-        filename = 'os-chmod-{}.py'
-        if six.PY2:
-            filename = filename.format('py2')
-        else:
-            filename = filename.format('py3')
         expect = {
             'SEVERITY': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 2, 'HIGH': 8},
             'CONFIDENCE': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 1, 'HIGH': 9}
         }
-        self.check_example(filename, expect)
+        self.check_example('os-chmod.py', expect)
 
     def test_os_exec(self):
         '''Test for `os.exec*`.'''
@@ -372,8 +355,8 @@ class FunctionalTests(testtools.TestCase):
     def test_random_module(self):
         '''Test for the `random` module.'''
         expect = {
-            'SEVERITY': {'UNDEFINED': 0, 'LOW': 6, 'MEDIUM': 0, 'HIGH': 0},
-            'CONFIDENCE': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 0, 'HIGH': 6}
+            'SEVERITY': {'UNDEFINED': 0, 'LOW': 7, 'MEDIUM': 0, 'HIGH': 0},
+            'CONFIDENCE': {'UNDEFINED': 0, 'LOW': 0, 'MEDIUM': 0, 'HIGH': 7}
         }
         self.check_example('random_module.py', expect)
 
@@ -757,6 +740,7 @@ class FunctionalTests(testtools.TestCase):
               "issue_severity": "HIGH",
               "issue_text": "%s",
               "line_number": 10,
+              "col_offset": 0,
               "line_range": [
                 10
               ],
