@@ -5,8 +5,8 @@
 
 import collections
 import tempfile
+from unittest import mock
 
-import mock
 import testtools
 
 import bandit
@@ -35,8 +35,9 @@ class TextFormatterTests(testtools.TestCase):
                           "{}   Severity: {}   Confidence: {}".
                           format(_indent_val, _issue.severity.capitalize(),
                                  _issue.confidence.capitalize()),
-                          "{}   Location: {}:{}".
-                          format(_indent_val, _issue.fname, _issue.lineno),
+                          "{}   Location: {}:{}:{}".
+                          format(_indent_val, _issue.fname, _issue.lineno,
+                                 _issue.col_offset),
                           "{}   More Info: {}".format(
                               _indent_val, docs_utils.get_url(_issue.test_id))]
             if _code:
@@ -53,6 +54,7 @@ class TextFormatterTests(testtools.TestCase):
         self.assertEqual(expected_return, issue_text)
 
         issue.lineno = ''
+        issue.col_offset = ''
         issue_text = b_text._output_issue_str(issue, indent_val,
                                               show_lineno=False)
         expected_return = _template(issue, indent_val, 'DDDDDDD')
