@@ -2,17 +2,7 @@
 #
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 """Tool for reporting Bandit coverage over OpenStack.
 
@@ -214,7 +204,7 @@ def run_bandit(source_dir):
         fail_results_dir = os.path.abspath('fail_results')
         os.mkdir(fail_results_dir)
     except OSError:
-        print ("Unable to make results directory")
+        print("Unable to make results directory")
 
     os.chdir(source_dir)
 
